FlexNet Embedded license administration
In addition to the License Portal, FlexNet Embedded license servers, clients and licenses can be accessed and managed using tools such as systemctl, Advantest FlexNet Embedded license server tools, and the Advantest FlexNet Embedded license client tools.
- Systemctl license server service administration
- Advantest FlexNet Embedded license server tools
- Advantest FlexNet Embedded license client tools
Systemctl license server service administration
The Advantest FlexNet Embedded license server runs as a standard Linux service and is controlled (starting, stopping, restarting, and displaying status) by systemctl. The license server can be used in a standalone system (not connected to a tester) providing licenses for tester workstations in the network. It can also be used to provide licenses primarily for the local attached tester. The license server uses the port 7070 which is opened in the firewall with the installation of the advantest-fne-server package.
Advantest FlexNet Embedded (FNE) license server commands
The Advantest FlexNet Embedded (FNE) license server is controlled using the systemctl tool.
Syntax: systemctl <option> advantest-fne-server
For example, to check if the server is running use the systemctl command with the status option:
systemctl status advantest-fne-serversystemctl status advantest-fne-server-viewer
systemctl command options
| Option | Description |
|---|---|
| help | Displays the manual page. |
| restart |
Stops and restarts the license server. |
| start |
Starts the license server. No status message is displayed if the start was successful. |
| status | Displays the status of the license server. |
| stop |
Stops the license server. No status message is displayed if the stop was successful. |
Firewall
The RHEL setup for V93000 tester workstations uses a firewall to control incoming connections. If the FNE license server is being used by multiple tester workstations connected to the network, SmarTest clients running on the local workstation where the license server is installed are not affected by the firewall. Outgoing connections from the local tester workstation to other license servers, even those accessible over the internet, are also not affected be the firewall. The FlexNet Embedded license server uses the port 7070 which is opened in the firewall by installing the advantest-fne-server (RPM) package.
Advantest FlexNet Embedded license server tools
Advantest FlexNet Embedded (FNE) license server tools are used to manage license servers, including registering and synchronizing license servers with the Advantest License Back-office, resetting the license server database, and displaying license server configurations and log files.
Advantest FlexNet Embedded license server tools usage
| Option | Description | ||
|---|---|---|---|
| reset-fne-server | Resets the license server database.
The license server is shutdown and requires restarting. |
||
| Location: | /opt/flexnetls/socbu/ | ||
| Options: |
-force -rules -all -help |
||
| Usage: | Requires root access. Without option: empties the license database on the FlexNet Embedded license server. A reset is also required to synchronize the FlexNet Embedded license server with the Advantest License back-office (online or offline). -force deletes the license database on the FlexNet Embedded license server. -rules deletes rules on the FlexNet Embedded license server. -all includes -force and -rules and remove backup configuration |
||
| Examples: | reset-fne-server -force
Successfully removed FNE database reset-fne-server
|
||
| register-fne-server |
Registers the license server at Advantest License Back-office. |
||
| Location: | /usr/local/bin/ | ||
| Options: |
nnnnn-ffff and binary response file |
||
| Usage: |
Used to initialize a new FlexNet Embedded license server. If the FlexNet Embedded license server has access to the internet, it will automatic synchronize with Advantest License back-office and the FlexNet Embedded license server is automatically registered. If the FlexNet Embedded license server is not connected to the internet, the synchronization must be carried out by up and down loading files. The LIC-SRV-Registraion_nnnn-ffff string is a unique key used to identify the FlexNet Embedded license server. It is displayed in the Advantest License Portal under Setup Server. |
||
| Examples: |
Online: register-fne-server 000601-ffffSuccessfully activated your server to ADVANTEST Offline: The register-fne-server 000601-ffff command creates a file to be uploaded using the Advantest License Portal to complete the registration. |
||
| fne-proxy-setup |
Configures the FNP component of a proxy failover setup. Run the fne-proxy-setup tool after fne-failover setup. |
||
| Location: | /opt/flexlm/bin | ||
| Usage: |
fne-proxy-setup <secondary host> <tertiary host> Use fully qualified host names. This tool uses ssh and sudo. You might be asked to enter your password several times. |
||
| sync-fne-server
(for online use) |
Synchronizes the license server with Advantest License Back-office. |
||
| Location: | /usr/local/bin/ | ||
| Usage: |
Used for FlexNet Embedded license servers connected to the internet to force a synchronization with Advantest License back-office for automatic license updates.
Note: FlexNet Embedded license servers connected to the internet automatically synchronize with the Advantest FlexNet License Back-Office every 12 hours. |
||
| fne-get-config | Displays the configuration items from the local FNE server. | ||
| Location: | /opt/flexnetls/socbu/ | ||
| Options: | --i[nstance] | Displays the value from the specified instance. | |
| --p[arent] | Displays the factory default value of the specified key. | ||
| --s[howconfig] | Displays the complete configuration, listing the keys and their values.
Examples of a key:-value pair displayed include: logging.threshold: LICENSING fne.syncTo.enabled: false lfs.syncTo.pagesize: 50 Configuration queries can also be limited by specifying a key. |
||
| --h[ostid] | Displays the host ID of the license server | ||
| --1 | Displays information for instance 1, listing the keys and their values.
Examples of key:-value pairs displayed include: id 1 serverInstanceId MYFIRSTLICSVR requestId 1 enterpriseId 12345678 pendingDeletion false ... Instances queries can also be limited by specifying a key. |
||
| --t[rusted-storage] |
Shows whether the license database (trusted storage) is consistent or not. Returns true or false.false response: the server is running but not able to serve licenses. |
||
| --d[etails] | Displays the company details (company name). | ||
| --m[achine]=host | Directs requests to the specified computer. | ||
| --b[uild] | Displays detailed information of the server build versions. | ||
| --help | Displays the help text. | ||
| --v[ersion] | Displays the version number of the fne-get-config tool. | ||
| Usage: |
fne-get-config [option] <key> |
||
| Examples: |
Display the value of a key, for example, the logging threshold value (LICENSING): |
fne-get-config logging.threshold LICENSING |
|
|
Show your company details: |
fne-get-config -d ADVANTEST_RD |
||
|
Show the host ID of the license server: |
fne-get-config -h 5543053D6573 |
||
|
Show the host ID of the specified license server: |
fne-get-config -m=fne_ls_1 -h 006046B1FD09 |
||
|
Show the host ID of the specified license server: |
fne-get-config -m=fne_ls_1 -h 006046B1FD09 |
||
| fne-status | Location: | /usr/bin/fne-status or /usr/local/bin/fne-status | |
| Usage: | If the FNE/FNX license server is running, the command returns a confirmation message. This tool give a compressive overview installed server, service and status and can be used to locate a root cause for a not function server. |
||
| Examples: |
Installed components:
Service status:
FNE server status:
FNP server status:
Configured servers: FNX-redundant advvm123/advvm124:advvm123.mycom.net |
||
| fne-handle-response | Checks the validity of the response file, and uploads, and downloads the response file to and from FNE server. | ||
| Location: | /usr/local/bin/fne-handle-response | ||
| Options: | --upload | Uploads the response file to the local FNE license server. | |
| --download | Downloads and saves the response file to the specified file for offline processing by the back-office server. | ||
| --show | Displays the content of the response file. | ||
| --notitle | Omits the title line in the listing (for scripting). | ||
| --ids |
Displays additional information, such as host IDs. |
||
| --help | Displays the help text. | ||
| --v[ersion] | Displays the version number of the fne-handle-response tool. | ||
| Usage: |
fne-handle-response -show|upload|-download [options] <response.bin> |
||
| Examples: |
Upload a response file: |
fne-handle-response --upload responsefile-2024-09-19_20-09-response.bin Successfully applied responsefile-2024-09-19_20-09-response.bin to FNE server |
|
|
Download a response file to file confirm.bin: |
fne-handle-response --download confirm.bin Successfully wrote confirm.bin |
||
|
Display a response file: |
fne-handle-response --show responsefile-2024-09-19_20-09-response.bin Name/Version x Count Start->Expires Conditions BitFailMap_HSM/1.0 x 1 14-sep-2024->21-sep-2024 BitFailMap_SOC/1.0 x 1 14-sep-2024->21-sep-2024 Company_Details/1.0 x 1000 7-dec-2021-> Company=Advantest_Training,Entity=DE E8015_A3-Model_upgrade/1.0 x 1 14-sep-2024->21-sep-2024 %%SERIALNUMBER:MY11223344%% MemoryTestPlusOffline_HSM/1.0 x 1 14-sep-2024->21-sep-2024 ... |
||
| showlog-fne-server |
Displays the license server log file. |
||
| Location | /opt/flexnetls/socbu/ | ||
| Options | Log level 1…8
Logfile <show specific logfile> -f - (follow) Show only the last 20 entries of the log file and "follow" any new entries |
||
| Usage | Log Levels:
|
||
| Examples |
showlog-fne-server -5
showlog-fne-server -6
|
||
| test_license_checkout | Tests the license checkout from a license server. | ||
| Prerequisite | The FNE client software must be installed on the FNE server workstation. | ||
| Location |
|
||
| Syntax: |
test_license_checkout -t <time in sec.> -f <feature name> |
||
| Options: | -t <time> | Specifies the time in seconds to be waited before checking in the license again.
Default period is 10 seconds. |
|
| -f [count] <feature[/version]> |
Specifies the license feature to be used for the license checkout test. This option can be applied multiple times. Default is dummy. Version defaults to 1.0. For example: Using FlexNetEmbedded 2023.09.1.292127 / subsystem 1.3 / built Feb 8 2024 16:00:57 (RPM) Check out finished in 46ms for category tplf OK 1 x dummy/1.0 Sleep for 0 seconds... |
||
| -d | Shows all debug/info messages (default: Only FATAL/ERROR)
To display all available information, use |
||
| -p <proj> | Sets project information. | ||
| -v <ssn> | Sets system serial number to <ssn>. | ||
| -o | Activates the isLicensingOk() thread, calling it every 20 seconds and creating the result output. |
||
| -l [<file>] | Replays the log file created by using SOCBU_LOG_REQUEST_FILE. | ||
| -u <name> | Sets the name of the upstream or device owner. | ||
| -c <name> | Sets device category (must follow a -u entry). | ||
| -e <ext> | Sets the hostid extension. | ||
| -m | Shows customer details provided by license server. | ||
| -g | Set feature checkout category; tool or tplf (default). | ||
| --help | Displays the help text. | ||
| Examples: |
To check that the FNE server is working after registration, enter: |
test_license_checkout
The tool attempts to checkout the dummy license from the FNE server, which is available after successful FNE server registration. |
|
|
Tests the license checkout for the Digital_E803x_100_200Mbps feature with count 1 (default count). After 60 seconds, the license is checked in. |
test_license_checkout -t 60 -f Digital_E803x_100_200Mbps | ||
| To check out the online SmarTest_SOC license with date version 2024.06 and system serial number DE04600001, enter the following command.
If the checkout succeeds, the license is checked out for 15 seconds. If it fails, it is not checked out. Date version is the master release date of the SmarTest version in use, documented in the SmarTest release notes. |
test_license_checkout -f SmarTest_SOC/2024.06 -v DE04600001 -t 15 | ||
| To check out a specified number of Digital_E8012_TIA floating licenses, enter the following command.
Three Digital_E8012_TIA floating licenses are checked out for the duration of 10 seconds. |
test_license_checkout -f 3 Digital_E8012_TIA -t 10 Example output: Using FlexNetEmbedded 2021.05.0.279614 / subsystem 1.3 / built Nov 8 2021 15:34:51 (RPM) Check out finished in 25ms for category tplf OK 1 x S&S_Tools_Package/1.0 Sleep for 0 seconds... |
||
| To check out S&S licenses, enter a command of the following form.
Use quotes to correctly specify special characters such as the & sign. |
test_license_checkout -f "S&S_Tools_Package" -t 0 | ||
| To check out a license with a device owner (only available for FNE client or on the FNE license server), enter a command of the following form.
The example requires a test program locked to the device owner ADVANTEST_RD. The token is Token_ADVANTEST_RD_WaferSort. The name of the device owner is set using the -u option. |
test_license_checkout -u ADVANTEST_RD -f Token_ADVANTEST_RD_WaferSort -t 0 | ||
|
The SOCBU_DIAGNOSTICS debug option is used to get more data and create an output file. If the checkout fails, please rerun the command with diagnostics enabled, enter the following command. |
Example for S&S licenses: SOCBU_DIAGNOSTICS=7 test_license_checkout -f "S&S_Tools_Package" -t 0 > /tmp/lic-error.txt Alternatively, the -d option can be used instead of SOCBU_DIAGNOSTICS: test_license_checkout -f SmarTest_SOC/2024.05 -v MY04605099 -t 0 -d > /tmp/lic-error.txt |
||
| fne-rules |
Manages the FNE pooling rules. (Imported in FNE 2024.10). Run the fne-proxy-setup tool after fne-failover setup. |
||
| Location: | /opt/flexnetls/socbu/ | ||
| Options: |
--upload [<model>] |
Uploads the model definition to the local FNE license server. If the model is not specified, stdin is used. The model is located at: /var/opt/flexnetls/socbu/model.current It is applied automatically after a reset of the database. |
|
| --show | Show current model definition | ||
| --delete | Deletes the model definition. | ||
| --help | Displays the fne-rules tool help text. | ||
| --version | Displays the version number of the fne-rules tool. | ||
| Usage: |
fne-rules -show|delete|-upload [<model>] |
||
| fne-log-collect |
Collects all relevant log file information from the FNX server for a given time. (Imported in FNE 2024.10). Run the fne-proxy-setup tool after fne-failover setup. |
||
| Location: | /opt/flexnetls/socbu/ | ||
| Options: |
--r[ange] |
Length of the interval in hours before and after the given time to be collected. Default: 4 hrs. | |
| --d[ay] |
Day of incident. Format: [[%Y-]%m]%d Default: today/yesterday |
||
| --t[ime] |
Time of incident. Format: %H[:%M[:%S]] |
||
| --p[rogress] |
Displays progress information. |
||
| --o[nly] |
Check only one process: fne/proxy/access/viewer |
||
| --c[eckPerformance] |
Analyze the log file and present statistics on the server load. |
||
| --h[elp] | Displays the fne-log-collect tool help text. | ||
| --v[ersion] | Displays the version number of the fne-log-collect tool. | ||
| Usage: |
fne-log-collect -t <time> [options] |
||
| Examples |
Collect logs from 3 a.m. today/yesterday: fne-log-collect -t 3 Collect logs from 2 p.m. to 4 p.m. on 1st April: fne-log-collect -t 15 -d 04-01 -r 1 Collect the logs for the whole of 1st April: fne-log-collect -t 12 -d 04-01 -r 12 Collect a short snapshot for the precise time of the FNP2FNE-proxy: fne-log-collect -t 09:10:11 -d 2022-04-01 -r 1 -o proxy |
||
Advantest FlexNet Embedded license client tools
Advantest FlexNet Embedded (FNE) license client tools are used to manage license clients, including testing license checkouts from a license server and listing all checked out licenses.
Advantest FlexNet Embedded license client tools usage
The following table lists the available Advantest FlexNet Embedded (FNE) license client tools and their usage:
| Option | Description | |
|---|---|---|
| test_license_checkout | Tests the license checkout from a license server. | |
| Location: | /opt/hp93000/soc64_<version>/.service/bin/ | |
| Examples: | test_license_checkout -t 60 -f SmarTest_SOC | |
| Syntax: |
test_license_checkout -t <time in sec.> -f <feature name> |
|
| fne-show-license-usage |
Iterates through the FlexNet Embedded servers defined in /etc/fne/client.conf and lists all checked out licenses. |
|
| Location: | /usr/local/bin (If the FNE client package is installed) | |
| Options: |
-a[ll], -h[elp] and -v[ersion] |
|
| Usage: |
-a - Shows all clients managed by the servers (default: Only clients on the local machine). -h - Shows the help information. -v - Displays the version of the fne-show-license-usage tool. |
|
| fne-list-licenses | Iterates through the FlexNet Embedded servers defined in /etc/fne/client.conf and lists all licenses (used and available).
Provides detailed information about the available licenses including:
|
|
| Location: | /usr/local/bin (If the FNE client package is installed) | |
| Options: |
<no option>, --feature, --expires, --assetScale, and -h[elp] |
|
| Usage for general options: |
No option: Lists licenses provided by all servers. --feature=<xyz> - Lists only licenses of the specified feature. --expires[=<n>] - Lists only licenses expiring in the next n days. Default for n: 30. --assetScale - Lists the AssetScale tokens and shows their content. --v[ersion] - Displays the tool version information. |
|
| Usage for tabular output options: |
Note: Options are processed in the order that they are stated. Use --sep and --notitle before --csv. --sep[arator]=<d> - Defines column separator for csv output: Defaults to ",".
--notitle - Omits title line in csv output (for scripting). --listtokens - Shows all currently available tokens for csv output.
Note: At least one license must be borrowed to show complete list. --match=<list of filters> - Filter shown borrow records.
--csv=<list of tokens> - Show licenses borrowed in csv format.
Note: There is always one line per feature. |
|
| fne-clear-SmarTest-licenses.sh |
Clears orphaned licenses from crashed SmarTest sessions on FNE servers. (Available from FNE 2024.10). Installed as part of the FNE client package. Executed on the system controller (FNE license client workstation). |
|
|
Location: |
/usr/local/ (If the FNE client package is installed) |
|
| Options: |
<no option>, --v[ersion],--h[elp] |
|
| Usage: |
No option: Clears licenses. --v[ersion] - Displays the tool version information. --h[elp] - Prints the help information. |
|
Example
Usage examples for the fne-list-licenses tool
List licenses provided by all servers:
$ fne-list-licenses
Server: Feature Server (redundant)
\-URL: http://fne1.domain.com:7070/fne/bin/capability
-SEL: DEVICEOWNER:UPSTREAM
100000 x Digital_E803x_E8070_16_32MB/1.0
100000 x Digital_E803x_E8070_32_64MB/1.0
100000 x Digital_E803x_E8070_64_112MB/1.0
...
List all licenses expiring in the next 28 days (request date 30.04.2018).
$ fne-list-licenses --expires=28
Server: Feature Server (redundant)
\-URL: http://fne1.domain.com:7070/fne/bin/capability
-SEL: DEVICEOWNER:UPSTREAM
100000 x Digital_E803x_E8070_16_32MB/1.0 expires 2018-05-28
...
List licenses of all features including the string Company:
$ fne-list-licenses --feature=Company_
Server: Feature Server (redundant)
\-URL: http://fneserver.domain.com:7070/fne/bin/capability
1000 x Company_Details/1.0
Company=COMPANY_NAME
List AssetScale tokens and show their content:
$ fne-list-licenses --assetScale
Server: Feature Server (redundant)
\-URL: http://fneserver.domain.com:7070/fne/bin/capability
123 x Token_OWNER_BRAND_PremiumTier/1.0
Locked to DeviceOwner=OWNER_BRAND
Content of AssetScale bundle:
1 x ANALOG_E9723B_MEAS_4_8/1.0
...
Show usage of a specific feature:
$ fne-list-licenses ---notitle -m featureName=Digital_E803x_E8070_16_32MB -csv featureCount,used,featureName
100000,10,Digital_E803x_E8070_16_32MB
Show all licenses locked to a DeviceOwner:
$ fne-list-licenses --match selectorsDictionary.DeviceOwner=UPSTREAM -csv server.name,featureName server.name,featureName
Feature Server (redundant),Token_UPSTREAM_PremiumTier
Clear the licenses currently in use on the client:
$ fne-clear-SmarTest-licenses.sh
Clearing borrowed licenses for device id 6451063D7784.starter_2tplf
Returns a message describing the devices for which the licenses are being cleared:
Clearing borrowed licenses for device id 6451063D7784.starter_2tplf